@@ -12,9 +12,6 @@ from trytond.transaction import Transaction
 from trytond.tools import grouped_slice
 
 
-__all__ = ['Level', 'ProcessDunning', 'Letter']
-
-
 class Level(metaclass=PoolMeta):
     __name__ = 'account.dunning.level'
     print_on_letter = fields.Boolean('Print on Letter')
@@ -30,9 +27,7 @@ class ProcessDunning(metaclass=PoolMeta):
         cls._actions.append('print_letter')
 
     def do_print_letter(self, action):
-        pool = Pool()
-        Dunning = pool.get('account.dunning')
-        dunnings = Dunning.browse(Transaction().context['active_ids'])
+        dunnings = self.records
         ids = [d.id for d in dunnings
             if d.state == 'waiting'
             and not d.blocked
